from seed.drives.impala import Impala
from seed.drives.mysql import MySQL
from seed.drives.postgresql import PostgreSQL


ALL_DRIVES = {
    # 'impala': Impala,
    'mysql': MySQL,
    'postgresql': PostgreSQL
}